import os
from pypinyin import lazy_pinyin
from datetime import datetime
from .encoding_test import detect_file_encoding

roman_to_chinese = {
    'Ⅰ': '一', 'Ⅱ': '二', 'Ⅲ': '三', 'Ⅳ': '四', 'Ⅴ': '五',
    'Ⅵ': '六', 'Ⅶ': '七', 'Ⅷ': '八', 'Ⅸ': '九', 'Ⅹ': '十', 
	'Ⅺ': '十一', 'Ⅻ': '十二', 'ⅩⅢ': '十三', 'ⅩⅣ': '十四', 'ⅩⅤ': '十五',
	'ⅩⅥ': '十六', 'ⅩⅦ': '十七', 'ⅩⅧ': '十八', 'ⅩⅨ': '十九', 'ⅩⅩ': '二十',
    'α': '阿尔法', 'β': '贝塔', 'γ': '伽玛', 'δ': '德尔塔', 'ε': '艾普西龙',
	'ζ': '泽塔', 'η': '伊塔', 'θ': '西塔', 'ι': '艾欧塔', 'κ': '喀帕',
    'λ': '拉姆达', 'μ': '缪', 'ν': '纽', 'ξ': '克西', 'ο': '欧米克戎',
    'π': '派', 'ρ': '柔', 'σ': '西格玛', 'τ': '陶', 'υ': '宇普西龙',
    'φ': '菲', 'χ': '卡伊', 'ψ': '普赛', 'ω': '欧米伽'

}

def replace_roman_with_chinese(text):
    for roman, chinese in roman_to_chinese.items():
        text = text.replace(roman, chinese)
    return text

def main(input_file, output_path):
	# 确保文件编码正确读入，并在输出时转为gbk
	encoding = detect_file_encoding(input_file)
	
	current_time = datetime.now().strftime('%Y-%m-%d_%H-%M-%S')
	output_file = os.path.join(output_path, f'simple_chinese_output_{current_time}.dict.yaml')
	with open(input_file, 'r', encoding=encoding) as infile, open(output_file, 'w', encoding='utf-8') as outfile:
		outfile.write(
			"# 生成工具 https://github.com/whitewatercn/rimetool\n" +
			"# 生成时间 " + current_time + "\n" +
			"---\n"
		)
		# 遍历输入文件的每一行

		for line in infile:
			content = line
			words = content.rstrip('\n').split('\t')
			new_line = words[0]
			pinyin_line = replace_roman_with_chinese(new_line) # 将罗马数字转换为中文数字
			pinyin_line = pinyin_line.replace('-', '')  # 删除所有的 '-'
			pinyin = ' '.join(lazy_pinyin(pinyin_line))
			# 在行的内容后面加一个tab，然后加上它的拼音，再加一个tab，然后加上数字1
			new_line_with_pinyin = new_line + '\t' + pinyin + '\t1\n'
			outfile.write(new_line_with_pinyin)
		print(f"已生成文件 {os.path.abspath(outfile.name)}")

if __name__ == "__main__":
    main()


from pypinyin import lazy_pinyin
import re


def pinyin_process(input_character):
	content = input_character
	words = content.rstrip('\n').split('\t')
	new_line = words[0]
	new_line = re.sub(r'[^\w]', '', new_line)  # 移除标点符号和空格
	output_pinyin = ' '.join(lazy_pinyin(new_line))
	return output_pinyin


import os
from rimetool.utils import vcf
from rimetool.utils import singleword
from rimetool.utils import singlechinese
from rimetool.utils import tosougou
import argparse

help_text = """

参数说明:

| 参数            | 说明      | 简化形式 |
| ------------- | ------- | ---- |
| --input-path  | 输入文件路径  | -i   |
| --output-path | 输出路径    | -o   |
| --tool        | 启用工具    | -t   |
| --mode        | 工具的详细功能 | -m   |
|               |         |      |

工具说明:

| 参数                    | 说明                                               | 备注                   |
| --------------------- | ------------------------------------------------ | -------------------- |
| --tool vcf            | 用于将联系人文件（.vcf）导出为rime词库                          |                      |
| --tool simple-english | 将单个词（如hello）或单个词组（如hello world）文件（.txt）导出为rime词库 | simple-english可简化为se |
| --tool simple-chinese | 将单个中文词组（如你好）文件（.txt）导出为rime词库                    | simple-chinese可简化为sc |
| --tool tosougou       | 将rime词库导出为搜狗txt词库                                |                      |
| --tool epub           | epub相关功能，需指定--mode参数                             |                      |

epub模式说明:

| 参数       | 模式                | 说明               |
| -------- | ----------------- | ---------------- |
| --mode 1 | epub_to_txt       | 将EPUB转换为纯文本      |
| --mode 2 | txt_to_short_long | 将文本转换为短句和长句      |
| --mode 3 | txt_to_rime       | 将文本转换为rime格式     |
| --mode 4 | epub_to_rime      | 完整的EPUB到rime转换流程 |

"""

# 定义模式映射
mode_choices = {
    '1': 'epub_to_txt',
    '2': 'txt_to_short_long',
    '3': 'txt_to_rime',
    '4': 'epub_to_rime',
    'epub_to_txt': 'epub_to_txt',
    'txt_to_short_long': 'txt_to_short_long',
    'txt_to_rime': 'txt_to_rime',
    'epub_to_rime': 'epub_to_rime'
}

def get_args_parser(add_help=True):
    parser = argparse.ArgumentParser(description=help_text, add_help=add_help, formatter_class=argparse.RawTextHelpFormatter)
    parser.add_argument('--input-path', '-i', required=True, type=str)
    parser.add_argument('--output-path', '-o', default='./rimetool_output', type=str)
    parser.add_argument('--tool', '-t', required=True, choices=['vcf','simple-english','se','simple-chinese','sc','tosougou','epub','hello'], type=str)
    parser.add_argument('--mode', '-m', required=False, choices=list(mode_choices.keys()))
    return parser

def main():
    parser = get_args_parser()
    args = parser.parse_args()
    
    if not os.path.exists(args.output_path):
        os.makedirs(args.output_path)
    os.makedirs(args.output_path, exist_ok=True)
    if args.tool == 'vcf':
        vcf.main(args.input_path, args.output_path)
    elif args.tool in ['simple-english', 'se']:
        simple_english.main(args.input_path, args.output_path)
    elif args.tool in ['simple-chinese', 'sc']:
        simple_chinese.main(args.input_path, args.output_path)
    elif args.tool == 'tosougou':
        tosogou.main(args.input_path, args.output_path)
    elif args.tool == 'epub':
        output_dir = args.output_path
        output_files = {
            'clean': os.path.join(output_dir, "epub转txt.txt"),
            'short': os.path.join(output_dir, "短句拆分.txt"),
            'long': os.path.join(output_dir, "长句拆分.txt")
        }
        processor = Epub_Processor.EpubProcessor(args.input_path, output_dir, output_files)
        
        mode = mode_choices[args.mode]
        if mode == 'epub_to_txt':
            processor.epub_to_txt()
        elif mode == 'txt_to_short_long':
            processor.txt_to_short_long(args.input_path, output_files)
        elif mode == 'txt_to_rime':
            processor.txt_to_rime_all(output_files)
        elif mode == 'epub_to_rime':
            processor.epub_to_rime(output_files)
        else:
            raise ValueError('请选择正确的EPUB处理模式')
    else:
        raise ValueError('请选择正确的工具。')

if __name__ == "__main__":
    main()


from datetime import datetime
import re
import os

def main(input_file, output_path):
	current_time = datetime.now().strftime('%Y-%m-%d_%H-%M-%S')
	output_file = os.path.join(output_path, f'simple_english_output.dict_{current_time}.yaml')

	with open(input_file, 'r') as infile, open(output_file, 'w+') as outfile:
		outfile.write(
			"# 生成工具 https://github.com/whitewatercn/rimetool\n" +
			"# 生成时间 " + current_time + "\n" +
			"---\n"
		)
		for line in infile:
			content = line
			words = content.rstrip('\n').split('\t')
			new_line = words[0]
			new_line_without_dash = new_line.replace('-', '')

			new_line_output = new_line + '\t' + new_line_without_dash + '\t1\n'



			# # 删除原单词的标点符号、空格
			# line_without_space = re.sub(r'[^\w\s]', '', line).replace(' ','').strip()
			# # 原单词+ tab + 去掉符合、空格的单词 + tab + 1
			# new_line = str(line.strip() + '\t' + line_without_space + '\t'+str(1) +'\n' )
			outfile.write(new_line_output)
		print(f"已生成文件 {os.path.abspath(outfile.name)}")



if __name__ == "__main__":
	main()